@@ -20,10 +20,13 @@ AboutData::AboutData()
                  KAboutLicense::GPL_V2,
                  i18n("Copyright © 2007–%1 KAddressBook authors", QStringLiteral("2024")))
 {
-    addAuthor(i18n("Laurent Montel"), i18n("Current maintainer"), QStringLiteral("montel@kde.org"));
-    addAuthor(i18n("Tobias König"), i18n("Previous maintainer"), QStringLiteral("tokoe@kde.org"));
-    addAuthor(i18n("Stefan Taferner"), i18n("Original Author (1998)"), QStringLiteral("taferner@kde.org"));
-    addAuthor(i18n("David Bryant"), i18n("Documentation (2019)"), QStringLiteral("davidbryant@gvtc.com"), QStringLiteral("https://davidcbryant.net"));
+    addAuthor(i18nc("@info:credit", "Laurent Montel"), i18n("Current maintainer"), QStringLiteral("montel@kde.org"));
+    addAuthor(i18nc("@info:credit", "Tobias König"), i18n("Previous maintainer"), QStringLiteral("tokoe@kde.org"));
+    addAuthor(i18nc("@info:credit", "Stefan Taferner"), i18n("Original Author (1998)"), QStringLiteral("taferner@kde.org"));
+    addAuthor(i18nc("@info:credit", "David Bryant"),
+              i18n("Documentation (2019)"),
+              QStringLiteral("davidbryant@gvtc.com"),
+              QStringLiteral("https://davidcbryant.net"));
 }
 
 AboutData::~AboutData() = default;
