@@ -7,6 +7,7 @@
 */
 
 #include "mainwindow.h"
+#include "config-kaddressbook.h"
 #include "mainwidget.h"
 #include "settings.h"
 #include "whatsnew/whatsnewtranslations.h"
@@ -68,7 +69,7 @@ MainWindow::MainWindow()
     mainWidgetLayout->setContentsMargins({});
     mainWidgetLayout->setSpacing(0);
     if (PimCommon::NeedUpdateVersionUtils::checkVersion()) {
-        const auto status = PimCommon::NeedUpdateVersionUtils::obsoleteVersionStatus(KAboutData::applicationData().version(), QDate::currentDate());
+        const auto status = PimCommon::NeedUpdateVersionUtils::obsoleteVersionStatus(QLatin1String(KADDRESSBOOK_RELEASE_VERSION_DATE), QDate::currentDate());
         if (status != PimCommon::NeedUpdateVersionUtils::ObsoleteVersion::NotObsoleteYet) {
             auto needUpdateVersionWidget = new PimCommon::NeedUpdateVersionWidget(this);
             mainWidgetLayout->addWidget(needUpdateVersionWidget);
