@@ -23,6 +23,7 @@
 
 using namespace KABPrinting;
 using namespace KAddressBookImportExport;
+using namespace Qt::Literals::StringLiterals;
 
 const char *CompactStyleConfigSectionName = "CompactStyle";
 const char *WithAlternating = "WithAlternating";
@@ -41,7 +42,7 @@ public:
     explicit CompactStyleForm(QWidget *parent)
         : QWidget(parent)
     {
-        setObjectName(QLatin1StringView("AppearancePage"));
+        setObjectName("AppearancePage"_L1);
         setupUi(this);
     }
 };
@@ -68,8 +69,8 @@ QString CompactStyle::contactsToHtml(const KContacts::Addressee::List &contacts)
     }
 
     QString content = QStringLiteral("<html>\n");
-    content += QLatin1String(" <body>\n");
-    content += QLatin1String("  <table style=\"font-size:50%; border-width: 0px; \"width=\"100%\">\n");
+    content += " <body>\n"_L1;
+    content += "  <table style=\"font-size:50%; border-width: 0px; \"width=\"100%\">\n"_L1;
 
     bool odd = false;
     for (const KContacts::Addressee &contact : contacts) {
@@ -83,21 +84,21 @@ QString CompactStyle::contactsToHtml(const KContacts::Addressee::List &contacts)
             }
         }
 
-        content += QLatin1String("   <tr>\n");
+        content += "   <tr>\n"_L1;
         QString style = QStringLiteral("background-color:");
         if (this->withAlternating) {
             style += (odd) ? this->firstColor.name() : this->secondColor.name();
         } else {
-            style += QLatin1String("#ffffff");
+            style += "#ffffff"_L1;
         }
-        content += QLatin1String("    <td style=\"") + style + QLatin1String(";\">") + values.join(QLatin1String("; ")) + QLatin1String("</td>\n");
-        content += QLatin1String("   </tr>\n");
+        content += QLatin1StringView("    <td style=\"") + style + QLatin1StringView(";\">") + values.join("; "_L1) + "</td>\n"_L1;
+        content += "   </tr>\n"_L1;
         odd = !odd;
     }
 
-    content += QLatin1String("  </table>\n");
-    content += QLatin1String(" </body>\n");
-    content += QLatin1String("</html>\n");
+    content += "  </table>\n"_L1;
+    content += " </body>\n"_L1;
+    content += "</html>\n"_L1;
 
     return content;
 }
@@ -114,7 +115,7 @@ CompactStyle::CompactStyle(PrintingWizard *parent)
     connect(mPageSettings->cbAlternating, &QCheckBox::clicked, this, &CompactStyle::setAlternatingColors);
 
     // set the controls, with the values in config
-    KConfigGroup config(KSharedConfig::openConfig(), QLatin1String(CompactStyleConfigSectionName));
+    KConfigGroup config(KSharedConfig::openConfig(), QLatin1StringView(CompactStyleConfigSectionName));
 
     withAlternating = config.readEntry(WithAlternating, true);
     withHomeAddress = config.readEntry(WithHomeAddress, true);
@@ -148,7 +149,7 @@ void CompactStyle::print(const KContacts::Addressee::List &contacts, PrintProgre
     withEMail = mPageSettings->cbWithEMail->isChecked();
 
     // to config
-    KConfigGroup config(KSharedConfig::openConfig(), QLatin1String(CompactStyleConfigSectionName));
+    KConfigGroup config(KSharedConfig::openConfig(), QLatin1StringView(CompactStyleConfigSectionName));
 
     config.writeEntry(WithAlternating, withAlternating);
     config.writeEntry(FirstColor, firstColor);
