@@ -39,9 +39,7 @@ StylePage::StylePage(QWidget *parent, const QString &name)
     connect(mStyleCombo, &QComboBox::activated, this, &StylePage::styleChanged);
 }
 
-StylePage::~StylePage()
-{
-}
+StylePage::~StylePage() = default;
 
 void StylePage::setPreview(const QPixmap &pixmap)
 {
@@ -181,3 +179,5 @@ void StylePage::setPrintingStyle(int index)
 {
     mStyleCombo->setCurrentIndex(index);
 }
+
+#include "moc_stylepage.cpp"
